function [ pvals ] = app1_allTFs( tfs, tgs, de_genes, M )
% tfs: list of TFs in ORTI, one at a line (can be either all TFs, or only
% with rank 1, or any subset of intrest)
%
% tgs: list of TGs for each TF in tfs, i.e., row i contains the list of
% TGs of TF_i in the ith row of tfs. This may include either all TGs or
% only those with rank 1
%
% de_genes: list of differentially expressed genes in the context of
% intrest, one gene at each line.
%
% M: total number of TF-TG intreactions in ORTI. For current version (Aug 2015):
% M = 10,370 if only Rank 1% pairs are considered (recommaded).
% M = 72,738 if all ranks are considered.
%
% pvals, the probabilities of TFs' overrepresentation in the context of
% intrest (unadjusted), i.e., line i gives the p-value of TF_i in tfs

fileID1 = fopen('app1_results.csv','w');
fprintf(fileID1,'TF_Symbol,p-value\n');

[tfs_size, ~ ] = size(tfs);
pvals = ones(tfs_size,1);

for i = 1:tfs_size
    tmp = tgs(i,:);
    tgs_i = tmp(~cellfun('isempty',tmp)); % remove empty cells
    N = numel(intersect(tgs,de_genes));
    K = numel(tgs_i);
    x = numel(intersect(tgs_i,de_genes));

% p  = hygecdf(x,M,K,N) : p is the probability of drawing up to x of a possible 
% K items in N drawings without replacement from a group of M objects.
% M: population size (total number of TF-TG interactions)
% K: total number of TGs annotated as being regulated by TF_i in  ORTI
% (i.e.,  all TGs in  line i of tgs))
% N: number of de_genes annotated as the TFs' targets in ORTI

    pvals(i) = (1 - hygecdf(x,M,K,N)) + hygepdf(x,M,K,N); 
    
    fprintf(fileID1,'%s,%f\n',tfs{i},pvals(i));

end

fclose(fileID1);

end

