function [clusters, centres] = clustering( kernel_exp, thr, step )
%INPUT:
%kernel_exp: expressions of kernel genes/probes over the specified conditions, a 
%numeric matrix s.t. each row corresponds to the expression vector of a kernel gene
%
%thr: cut-off threshold (critical correlation)
%step: step size for loosing the cut-off
%
%OUTPUT:
%clusters: clusters are stored as cell arrey where each cell element correspond to a cluster
%containing the set of kernel gene ids (1,...,n where n is the size of kernel set) within that clister
%
%centres: a numeric array of kernel gene ids s.t. its i_th element gives the id of the centre of i_th 
%cluster stored in "clusters" cell array


%initial correlation 
cut_off = 0.9;

% Initial clusters
clusters = initial_clus(kernel_exp, cut_off);

% update centers
centres = update_centres(clusters, kernel_exp);

cut_off = cut_off - step;

while cut_off >= thr
    tmp = combine_clus(kernel_exp, clusters, centres, cut_off);
    clusters = tmp;
    centres = update_centres(clusters, kernel_exp);
    cut_off = cut_off - step;
end
centres = update_centres(clusters,kernel_exp);

end

